ctFitCovCheckPlot: ctFitCovCheckPlot

ctFitCovCheckPlotR Documentation

ctFitCovCheckPlot

Description

Plot the results of ctFitCovCheck.

Usage

ctFitCovCheckPlot(x, maxlag = 10, vars = NA, splitvar = NA, cor = FALSE, ...)

Arguments

x

Data output from 'ctFitCovCheck(..., plot = FALSE)'. If a ggplot object or list of ggplot objects is supplied, it is returned unchanged.

maxlag

Maximum lag to plot.

vars

Optional character vector of variable names to plot. If 'NA', all variables are plotted.

splitvar

Optional character string specifying a variable to split the plot by.

cor

Logical; if 'TRUE', plot correlations instead of covariances. (label change)

...

not used.

Value

ggplot object.

Examples

## Not run: 
ctFitCovCheckPlot(ctFitCovCheck(ctstantestfit,cor=TRUE,plot=FALSE),maxlag=3)

## End(Not run)

ctsem documentation built on June 30, 2026, 5:07 p.m.