powered by
Either to include different data, or because you have upgraded ctsem and the internal data structure has changed.
ctFitUpdate(oldfit, data = NA, recompile = FALSE, refit = FALSE, ...)ctStanFitUpdate(oldfit, data = NA, recompile = FALSE, refit = FALSE, ...)
ctStanFitUpdate(oldfit, data = NA, recompile = FALSE, refit = FALSE, ...)
updated ctStanFit object.
fit object to be upgraded
replacement long format data object
whether to force a recompile -- safer but slower and usually unnecessary.
if TRUE, refits the model using the old estimates as a starting point. Only applicable for optimized fits, not sampling.
extra arguments to pass to ctFit
newfit <- ctFitUpdate(ctstantestfit,refit=FALSE)
Run the code above in your browser using DataLab