Learn R Programming

ctsem (version 3.11.1)

ctFitUpdateModel: Update model/data for an already compiled and fit ctsem object

Description

Allows one to change data and or model elements that don't require recompiling, then re fit.

Usage

ctFitUpdateModel(fit, datalong, model, ..., ctstanmodel)

Arguments

fit

ctStanFit object

datalong

data as normally passed to ctFit

model

model as normally passed to ctFit

...

extra args for ctFit

ctstanmodel

Deprecated. Use model.