View source: R/ctCoverageCheck.R
| ctModelCoverage_check | R Documentation |
Performs a coverage check analysis by generating data from a model, fitting it multiple times with different fit arguments, and plotting the results.
ctModelCoverage_check(
initialData,
fitting_model,
niter,
fit_args,
cores = 10,
fit_cores = 1,
generate_cores = fit_cores,
plot_every = max(c(10, cores))
)
initialData |
An initial dataset to fit to determine 'true' parameters for further generation. |
fitting_model |
A ctModel object used for fitting the data |
niter |
Number of iterations to run |
fit_args |
Named list of fit argument sets to test (e.g., list(boot = list(optimcontrol = list(uncertainty = 'bootstrap')), hess = list(optimcontrol = list(uncertainty = 'hessian')))) |
cores |
Number of outer simulation iterations to run in parallel.
Inner model fits use |
fit_cores |
Number of cores for each inner |
generate_cores |
Number of cores for |
plot_every |
Print plots every n iterations (default = 10) |
A list containing the results data.table and final plots
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.