Performs a coverage check analysis by generating data from a model, fitting it multiple times with different fit arguments, and plotting the results.
ctModelCoverage_check(
initialData,
fitting_model,
niter,
fit_args,
cores = 10,
fit_cores = 1,
generate_cores = fit_cores,
plot_every = max(c(10, cores))
)A list containing the results data.table and final plots
An initial dataset to fit to determine 'true' parameters for further generation.
A ctModel object used for fitting the data
Number of iterations to run
Named list of fit argument sets to test (e.g., list(boot = list(optimcontrol = list(uncertainty = 'bootstrap')), hess = list(optimcontrol = list(uncertainty = 'hessian'))))
Number of outer simulation iterations to run in parallel.
Inner model fits use fit_cores by default to avoid nested
parallelism.
Number of cores for each inner ctFit call.
This is enforced after merging each fit_args entry so that outer
simulation cores cannot accidentally be reused by worker fits.
Number of cores for ctGenerateFromFit
when generating replicated datasets. Defaults to fit_cores; set it
explicitly to use more cores for generation.
Print plots every n iterations (default = 10)