| ctOptimUncertainty | R Documentation |
Recomputes the approximate raw-parameter uncertainty for an optimized
ctFit object and refreshes the approximate raw-parameter
samples.
ctOptimUncertainty(
fit,
uncertainty = c("hessian", "surrogate", "bootstrap", "fullbootstrap", "sandwich",
"opg"),
draws = c("auto", "normal", "empirical", "imis"),
finishsamples = NULL,
cores = NULL,
control = list(),
verbose = 0,
...
)
fit |
Optimized |
uncertainty |
Uncertainty approximation. |
draws |
Approximate raw-parameter draw method. |
finishsamples |
Number of approximate raw-parameter samples. |
cores |
Number of cores. Hessian, surrogate, and IMIS calculations use these cores by splitting each log-probability/gradient evaluation across subjects. Score-based methods use these cores for score contribution calculations. Transformed-quantity calculations also use these cores. |
control |
List of method-specific options. Useful entries include
|
verbose |
Integer controlling progress detail. |
... |
Unused. |
Updated ctStanFit object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.